# CSRReasonEnum

A certificate Signing Request (CSR) reason status.  pending: The certificate signing is in progress failed: The certificate failed to be issued. issued: The signed certificate has been successfully issued 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **str** | A certificate Signing Request (CSR) reason status.  pending: The certificate signing is in progress failed: The certificate failed to be issued. issued: The signed certificate has been successfully issued  |  must be one of ["pending", "failed", "issued", ]
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


